<?php
/**
 * Plugin Name:           AutomatorWP - LearnDash
 * Plugin URI:            https://automatorwp.com/add-ons/learndash/
 * Description:           Connect AutomatorWP with LearnDash.
 * Version:               1.1.8
 * Author:                ایران تمز
 * Author URI:            https://iranthemes.com
 * Text Domain:           automatorwp-learndash
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          6.2
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               AutomatorWP\LearnDash
 * @author                AutomatorWP
 * @copyright             Copyright (c) AutomatorWP
 */

final class AutomatorWP_LearnDash {

    /**
     * @var         AutomatorWP_LearnDash $instance The one true AutomatorWP_LearnDash
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      AutomatorWP_LearnDash self::$instance The one true AutomatorWP_LearnDash
     */
    public static function instance() {
        if( !self::$instance ) {
            self::$instance = new AutomatorWP_LearnDash();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'AUTOMATORWP_LEARNDASH_VER', '1.1.8' );

        // Plugin file
        define( 'AUTOMATORWP_LEARNDASH_FILE', __FILE__ );

        // Plugin path
        define( 'AUTOMATORWP_LEARNDASH_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'AUTOMATORWP_LEARNDASH_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            // Triggers
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/view-quiz.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/view-lesson.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/view-topic.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/view-course.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/complete-quiz.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/complete-quiz-percentage.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/complete-topic.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/complete-topic-category.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/complete-topic-tag.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/complete-lesson.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/complete-lesson-category.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/complete-lesson-tag.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/enroll-course.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/enroll-course-category.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/enroll-course-tag.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/complete-course.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/complete-course-category.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/complete-course-tag.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/add-group.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/upload-assignment.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/triggers/approve-assignment.php';

            // Actions
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/actions/reset-quiz.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/actions/mark-topic.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/actions/mark-lesson.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/actions/mark-lesson-assignments.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/actions/mark-course-assignments.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/actions/user-course.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/actions/mark-course.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/actions/reset-course.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/actions/create-group.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/actions/user-group.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/actions/user-group-leader.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/actions/email-groups-leaders.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/actions/email-certificate.php';

            // Filters
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/filters/user-has-completed-course.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/filters/user-has-not-completed-course.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/filters/user-is-added-group.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/filters/user-is-not-added-group.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/filters/user-is-enrolled-course.php';
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/filters/user-is-not-enrolled-course.php';

            // Includes
            require_once AUTOMATORWP_LEARNDASH_DIR . 'includes/functions.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {

        add_action( 'automatorwp_init', array( $this, 'register_integration' ) );

        add_filter( 'automatorwp_licenses_meta_boxes', array( $this, 'license' ) );

        // Setup our activation and deactivation hooks
        register_activation_hook( __FILE__, array( $this, 'activate' ) );
        register_deactivation_hook( __FILE__, array( $this, 'deactivate' ) );

        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Registers this integration
     *
     * @since 1.0.0
     */
    function register_integration() {

        automatorwp_register_integration( 'learndash', array(
            'label' => 'LearnDash',
            'icon'  => AUTOMATORWP_LEARNDASH_URL . 'assets/learndash.svg',
        ) );

    }

    /**
     * Licensing
     *
     * @since 1.0.0
     *
     * @param array $meta_boxes
     *
     * @return array
     */
    function license( $meta_boxes ) {

        $meta_boxes['automatorwp-learndash-license'] = array(
            'title' => 'LearnDash',
            'fields' => array(
                'automatorwp_learndash_license' => array(
                    'type' => 'edd_license',
                    'file' => AUTOMATORWP_LEARNDASH_FILE,
                    'item_name' => 'LearnDash',
                ),
            )
        );

        return $meta_boxes;

    }

    /**
     * Activation hook for the plugin.
     *
     * @since  1.0.0
     */
    function activate() {

        if( $this->meets_requirements() ) {

        }

    }

    /**
     * Deactivation hook for the plugin.
     *
     * @since  1.0.0
     */
    function deactivate() {

    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.0
     */
    public function admin_notices() {

        if ( ! $this->meets_requirements() && ! defined( 'AUTOMATORWP_ADMIN_NOTICES' ) ) : ?>

            <div id="message" class="notice notice-error is-dismissible">
                <p>
                    <?php printf(
                        __( 'AutomatorWP - LearnDash requires %s and %s in order to work. Please install and activate them.', 'automatorwp-learndash' ),
                        '<a href="https://wordpress.org/plugins/automatorwp/" target="_blank">AutomatorWP</a>',
                        '<a href="http://www.learndash.com/" target="_blank">LearnDash</a>'
                    ); ?>
                </p>
            </div>

            <?php define( 'AUTOMATORWP_ADMIN_NOTICES', true ); ?>

        <?php endif;

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'AutomatorWP' ) ) {
            return false;
        }

        if ( ! class_exists( 'SFWD_LMS' ) ) {
            return false;
        }

        return true;

    }

    /**
     * Internationalization
     *
     * @access      public
     * @since       1.0.0
     * @return      void
     */
    public function load_textdomain() {

        // Set filter for language directory
        $lang_dir = AUTOMATORWP_LEARNDASH_DIR . '/languages/';
        $lang_dir = apply_filters( 'automatorwp_learndash_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale = apply_filters( 'plugin_locale', get_locale(), 'automatorwp-learndash' );
        $mofile = sprintf( '%1$s-%2$s.mo', 'automatorwp-learndash', $locale );

        // Setup paths to current locale file
        $mofile_local   = $lang_dir . $mofile;
        $mofile_global  = WP_LANG_DIR . '/automatorwp-learndash/' . $mofile;

        if( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/automatorwp-learndash/ folder
            load_textdomain( 'automatorwp-learndash', $mofile_global );
        } elseif( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/automatorwp-learndash/languages/ folder
            load_textdomain( 'automatorwp-learndash', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'automatorwp-learndash', false, $lang_dir );
        }

    }

}

/**
 * The main function responsible for returning the one true AutomatorWP_LearnDash instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \AutomatorWP_LearnDash The one true AutomatorWP_LearnDash
 */
function AutomatorWP_LearnDash() {
    return AutomatorWP_LearnDash::instance();
}
add_action( 'plugins_loaded', 'AutomatorWP_LearnDash' );
