<?php
/**
 * Mark Course Assignments
 *
 * @package     AutomatorWP\Integrations\LearnDash\Actions\Mark_Course_Assignments
 * @author      AutomatorWP <contact@automatorwp.com>, Ruben Garcia <rubengcdev@gmail.com>
 * @since       1.0.0
 */
// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

class AutomatorWP_LearnDash_Mark_Course_Assignments extends AutomatorWP_Integration_Action {

    public $integration = 'learndash';
    public $action = 'learndash_mark_course_assignments';

    /**
     * Register the trigger
     *
     * @since 1.0.0
     */
    public function register() {

        automatorwp_register_action( $this->action, array(
            'integration'       => $this->integration,
            'label'             => __( 'Mark user assignments from course as approved or not approved', 'automatorwp-learndash' ),
            'select_option'     => __( 'Mark user assignments from course as <strong>approved or not approved</strong>', 'automatorwp-learndash' ),
            /* translators: %1$s: Post title. %2$s: Operation (approved or not approved). */
            'edit_label'        => sprintf( __( 'Mark user assignments from %1$s as %2$s', 'automatorwp-learndash' ), '{post}', '{operation}' ),
            /* translators: %1$s: Post title. %2$s: Operation (approved or not approved). */
            'log_label'         => sprintf( __( 'Mark user assignments from %1$s as %2$s', 'automatorwp-learndash' ), '{post}', '{operation}' ),
            'options'           => array(
                'post' => automatorwp_utilities_post_option( array(
                    'name'              => __( 'Course:', 'automatorwp-learndash' ),
                    'option_none_label' => __( 'all courses', 'automatorwp-learndash' ),
                    'option_custom'         => true,
                    'option_custom_desc'    => __( 'Course ID', 'automatorwp-learndash' ),
                    'post_type'         => 'sfwd-courses',
                ) ),
                'operation' => array(
                    'from' => 'operation',
                    'fields' => array(
                        'operation' => array(
                            'name' => __( 'Operation:', 'automatorwp-learndash' ),
                            'type' => 'select',
                            'options' => array(
                                'approve'      => __( 'approved', 'automatorwp-learndash' ),
                                'not_approve'  => __( 'not approved', 'automatorwp-learndash' ),
                            ),
                            'default' => 'approve'
                        ),
                    )
                ),
            ),
        ) );

    }

    /**
     * Action execution function
     *
     * @since 1.0.0
     *
     * @param stdClass  $action             The action object
     * @param int       $user_id            The user ID
     * @param array     $action_options     The action's stored options (with tags already passed)
     * @param stdClass  $automation         The action's automation object
     */
    public function execute( $action, $user_id, $action_options, $automation ) {

        // Shorthand
        $operation = $action_options['operation'];
        $course_id = $action_options['post'];

        // Ensure operation default value
        if( empty( $operation ) ) {
            $operation = 'approve';
        }

        // Check specific lesson
        if( $course_id !== 'any' ) {

            // Get all course lessons IDs
            $lessons_query = new WP_Query( array(
                'fields'        => 'ids',
                'post_type'     => 'sfwd-lessons',
                'meta_query'    => array(
                    array(
                        'key'   => 'course_id',
                        'value' => $course_id,
                    ),
                ),
            ) );

            $lessons_ids = $lessons_query->get_posts();

            // Get user assignments IDs for the course lessons
            $query = new WP_Query( array(
                'fields'        => 'ids',
                'post_type'     => 'sfwd-assignment',
                'post_author'   => $user_id,
                'meta_query'    => array(
                    array(
                        'key'       => 'lesson_id',
                        'value'     => $lessons_ids,
                        'compare'   => 'IN',
                    ),
                ),
            ) );

        } else {

            // Get all user assignments IDs
            $query = new WP_Query( array(
                'fields'        => 'ids',
                'post_type'     => 'sfwd-assignment',
                'post_author'   => $user_id,
            ) );

        }

        $assignments_ids = $query->get_posts();

        // Loop assignments
        foreach ( $assignments_ids as $assignment_id ) {

            switch ( $operation ) {
                case 'approve':
                    // Mark assignment as approved
                    learndash_assignment_mark_approved( $assignment_id );

                    /**
                     * Fires after assignment is approved
                     *
                     * @since 2.2.0
                     *
                     * @param int $assignment_id Assignment ID.
                     */
                    do_action( 'learndash_assignment_approved', $assignment_id );
                    break;
                case 'not_approve':
                    // Mark assignment as not approved
                    update_post_meta( $assignment_id, 'approval_status', 0 );
                    break;
            }

        }



    }

}

new AutomatorWP_LearnDash_Mark_Course_Assignments();