<?php
/**
 * User Is Enrolled Course
 *
 * @package     AutomatorWP\Integrations\LearnDash\Filters\User_Is_Enrolled_Course
 * @author      AutomatorWP <contact@automatorwp.com>, Ruben Garcia <rubengcdev@gmail.com>
 * @since       1.0.0
 */
// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

class AutomatorWP_LearnDash_User_Is_Enrolled_Course_Filter extends AutomatorWP_Integration_Filter {

    public $integration = 'learndash';
    public $filter = 'learndash_user_is_enrolled_course';

    /**
     * Register the trigger
     *
     * @since 1.0.0
     */
    public function register() {

        automatorwp_register_filter( $this->filter, array(
            'integration'       => $this->integration,
            'label'             => __( 'User is enrolled in course', 'automatorwp-learndash' ),
            'select_option'     => __( 'User <strong>is enrolled</strong> in course', 'automatorwp-learndash' ),
            /* translators: %1$s: Course. */
            'edit_label'        => sprintf( __( '%1$s', 'automatorwp-learndash' ), '{post}'  ),
            /* translators: %1$s: Course. */
            'log_label'         => sprintf( __( '%1$s', 'automatorwp-learndash' ), '{post}' ),
            'options'           => array(
                'post' => automatorwp_utilities_post_option( array(
                    'name' => __( 'Course:', 'automatorwp-learndash' ),
                    'option_none_label' => __( 'any course', 'automatorwp-learndash' ),
                    'post_type' => 'sfwd-courses',
                    'default' => 'any'
                ) ),
            ),
        ) );

    }

    /**
     * User deserves check
     *
     * @since 1.0.0
     *
     * @param bool      $deserves_filter    True if user deserves filter, false otherwise
     * @param stdClass  $filter             The filter object
     * @param int       $user_id            The user ID
     * @param array     $event              Event information
     * @param array     $filter_options     The filter's stored options
     * @param stdClass  $automation         The trigger's automation object
     *
     * @return bool                          True if user deserves trigger, false otherwise
     */
    public function user_deserves_filter( $deserves_filter, $filter, $user_id, $event, $filter_options, $automation ) {

        // Shorthand
        $course = $filter_options['post'];

        if ($course !== 'any') {
            $course_name = get_post($course)->post_title;
        } else{
            $course_name = 'any course';
        }

        // Bail if wrong configured
        if( empty( $course ) ) {
            $this->result = __( 'Filter not passed. Course option has not been configured.', 'automatorwp-learndash' );
            return false;
        }

        // Get courses where the student is enrolled
        $courses = learndash_user_get_enrolled_courses( $user_id );

        // Don't deserve if user is not in this course
        if( ! in_array( $course, $courses ) &&  empty( $courses ) ) {
            $this->result = sprintf( __( 'Filter not passed. User is not enrolled in course "%1$s".', 'automatorwp-learndash' ),
                $course_name
            );
            return false;
        }

        $this->result = sprintf( __( 'Filter passed. User is enrolled in course "%1$s".', 'automatorwp-learndash' ),
            $course_name
        );

        return $deserves_filter;

    }

}

new AutomatorWP_LearnDash_User_Is_Enrolled_Course_Filter();